[cp-patches] Patch: GtkMouseDragGestureRecognizer implementation

2006-07-21 Thread Lillian Angel
Finished implementing GtkMouseDragGestureRecognizer.

2006-07-20  Lillian Angel  [EMAIL PROTECTED]

* gnu/java/awt/dnd/GtkMouseDragGestureRecognizer.java
(GtkMouseDragGestureRecognizer): New constructor.
(GtkMouseDragGestureRecognizer): New constructor.
(GtkMouseDragGestureRecognizer): New constructor.
(mouseClicked): Removed FIXME.
(mousePressed): Implemented.
(mouseReleased): Implemented.
(mouseEntered): Implemented.
(mouseDragged): Implemented to check mouse point and trigger 
origin.
(mouseMoved): Removed FIXME.
(getDropActionFromEvent): New helper function used to convert 
mouse event modifiers to a drop action.
* java/awt/dnd/DragSource.java
(getDragThreshold): Changed to return some arbitrary value for 
testing purposes.

Index: gnu/java/awt/dnd/GtkMouseDragGestureRecognizer.java
===
RCS file: /cvsroot/classpath/classpath/gnu/java/awt/dnd/GtkMouseDragGestureRecognizer.java,v
retrieving revision 1.1
diff -u -r1.1 GtkMouseDragGestureRecognizer.java
--- gnu/java/awt/dnd/GtkMouseDragGestureRecognizer.java	6 Jul 2006 19:47:05 -	1.1
+++ gnu/java/awt/dnd/GtkMouseDragGestureRecognizer.java	21 Jul 2006 20:40:14 -
@@ -39,7 +39,8 @@
 package gnu.java.awt.dnd;
 
 import java.awt.Component;
-import java.awt.dnd.DragGestureEvent;
+import java.awt.Point;
+import java.awt.dnd.DnDConstants;
 import java.awt.dnd.DragGestureListener;
 import java.awt.dnd.DragSource;
 import java.awt.dnd.MouseDragGestureRecognizer;
@@ -48,21 +49,31 @@
 public class GtkMouseDragGestureRecognizer
 extends MouseDragGestureRecognizer
 {
-  
+
   DragSource ds;
   Component c;
   int actions;
   DragGestureListener dgl;
+
+  public GtkMouseDragGestureRecognizer (DragSource ds)
+  {
+this(ds, null, 0, null);
+  }
+
+  public GtkMouseDragGestureRecognizer (DragSource ds, Component c)
+  {
+this (ds, c, 0, null);
+  }
   
-  GtkMouseDragGestureRecognizer()
+  public GtkMouseDragGestureRecognizer (DragSource ds, Component c, int act)
   {
-super(null);
+this(ds, c, act, null);
   }
   
   public GtkMouseDragGestureRecognizer (DragSource ds, Component c, int act,
 DragGestureListener dgl)
   {
-super (ds, c, act, dgl);
+super(ds, c, act, dgl);
 
 registerListeners();
 
@@ -74,37 +85,90 @@
   
   public void mouseClicked (MouseEvent e)
   {
-// FIXME: Not Implemented
+// Nothing to do here.
   }
 
   public void mousePressed (MouseEvent e)
   {
-// FIXME: Not Implemented
+events.clear();
+if (getDropActionFromEvent(e) != DnDConstants.ACTION_NONE)
+  appendEvent(e);
   }
 
   public void mouseReleased (MouseEvent e)
   {
-// FIXME: Not Implemented
+events.clear();
   }
 
   public void mouseEntered (MouseEvent e)
   {
-// FIXME: Not Implemented
+events.clear();
   }
 
-  public void mouseExited (MouseEvent e)
+  public void mouseExited(MouseEvent e)
   {
-// FIXME: Not Implemented
+if (!events.isEmpty())
+  if (getDropActionFromEvent(e) == DnDConstants.ACTION_NONE)
+events.clear();
   }
 
   public void mouseDragged(MouseEvent e)
   {
-dgl.dragGestureRecognized(new DragGestureEvent(this, actions, e.getPoint(),
-   events));
+if (!events.isEmpty())
+  {
+int act = getDropActionFromEvent(e);
+
+if (act == DnDConstants.ACTION_NONE)
+  return;
+
+Point origin = ((MouseEvent) events.get(0)).getPoint();
+Point current = e.getPoint();
+int dx = Math.abs(origin.x - current.x);
+int dy = Math.abs(origin.y - current.y);
+int threshold = DragSource.getDragThreshold();
+
+if (dx  threshold || dy  threshold)
+  fireDragGestureRecognized(act, origin);
+else
+  appendEvent(e);
+  }
   }
-
+  
   public void mouseMoved (MouseEvent e)
   {
-// FIXME: Not Implemented
+// Nothing to do here.
+  }
+
+  private int getDropActionFromEvent(MouseEvent e)
+  {
+int modEx = e.getModifiersEx();
+int buttons =  modEx  (MouseEvent.BUTTON1_DOWN_MASK
+   | MouseEvent.BUTTON2_DOWN_MASK | MouseEvent.BUTTON3_DOWN_MASK);
+if (!(buttons == MouseEvent.BUTTON1_DOWN_MASK || 
+buttons == MouseEvent.BUTTON2_DOWN_MASK))
+  return DnDConstants.ACTION_NONE;
+
+// Convert modifier to a drop action
+int sourceActions = getSourceActions();
+int mod = modEx
+   (MouseEvent.SHIFT_DOWN_MASK | MouseEvent.CTRL_DOWN_MASK);
+switch (mod)
+  {
+  case MouseEvent.SHIFT_DOWN_MASK | MouseEvent.CTRL_DOWN_MASK:
+return DnDConstants.ACTION_LINK  sourceActions;
+  case MouseEvent.CTRL_DOWN_MASK:
+return DnDConstants.ACTION_COPY  sourceActions;
+  case MouseEvent.SHIFT_DOWN_MASK:
+return 

Re: [cp-patches] FYI: GtkMouseDragGestureRecognizer implementation

2006-07-21 Thread Lillian Angel
I forgot to remove some unused fields in the last patch.

2006-07-20  Lillian Angel  [EMAIL PROTECTED]

* gnu/java/awt/dnd/GtkMouseDragGestureRecognizer.java:
Removed unused fields.
(GtkMouseDragGestureRecognizer): Removed initializations.


On Fri, 2006-07-21 at 16:45 -0400, Lillian Angel wrote:
 Finished implementing GtkMouseDragGestureRecognizer.
 
 2006-07-20  Lillian Angel  [EMAIL PROTECTED]
 
 * gnu/java/awt/dnd/GtkMouseDragGestureRecognizer.java
 (GtkMouseDragGestureRecognizer): New constructor.
 (GtkMouseDragGestureRecognizer): New constructor.
 (GtkMouseDragGestureRecognizer): New constructor.
 (mouseClicked): Removed FIXME.
 (mousePressed): Implemented.
 (mouseReleased): Implemented.
 (mouseEntered): Implemented.
 (mouseDragged): Implemented to check mouse point and trigger 
   origin.
 (mouseMoved): Removed FIXME.
 (getDropActionFromEvent): New helper function used to convert 
   mouse event modifiers to a drop action.
 * java/awt/dnd/DragSource.java
 (getDragThreshold): Changed to return some arbitrary value for 
   testing purposes.
 
Index: gnu/java/awt/dnd/GtkMouseDragGestureRecognizer.java
===
RCS file: /cvsroot/classpath/classpath/gnu/java/awt/dnd/GtkMouseDragGestureRecognizer.java,v
retrieving revision 1.2
diff -u -r1.2 GtkMouseDragGestureRecognizer.java
--- gnu/java/awt/dnd/GtkMouseDragGestureRecognizer.java	21 Jul 2006 20:44:30 -	1.2
+++ gnu/java/awt/dnd/GtkMouseDragGestureRecognizer.java	21 Jul 2006 21:04:17 -
@@ -50,11 +50,6 @@
 extends MouseDragGestureRecognizer
 {
 
-  DragSource ds;
-  Component c;
-  int actions;
-  DragGestureListener dgl;
-
   public GtkMouseDragGestureRecognizer (DragSource ds)
   {
 this(ds, null, 0, null);
@@ -76,11 +71,6 @@
 super(ds, c, act, dgl);
 
 registerListeners();
-
-this.ds = ds;
-this.c = c;
-this.actions = act;
-this.dgl = dgl;
   }
   
   public void mouseClicked (MouseEvent e)


Re: [cp-patches] JamVM sun.misc.Unsafe

2006-07-21 Thread Tom Tromey
 Casey == Casey Marshall [EMAIL PROTECTED] writes:

Casey I don't know what that suite is testing, but it isn't the version of
Casey JSR 166 that's in 1.5.

Our jsr 166 code comes from there.  They don't do release branches so
we've also picked up a bunch of 1.6 stuff from the import.

Tom



Re: [cp-patches] [RFC] speed up CairoSurface

2006-07-21 Thread Andreas Tobler

Hi Mark,

Mark Wielaard wrote:


On Sat, 2006-07-22 at 00:00 +0200, Andreas Tobler wrote:
But he also suggested to reorganise the code path to 
check for (ByteOrder.nativeOrder() == ByteOrder.BIG_ENDIAN) only once 
and not for all pixels. Thanks Assen!


I attach a patch which does this. The improvement is not bad, around a 
factor 5 for a BufferedImage 816x616 RGBA.


Comments? Ok for head?


Seems like a good idea!
Just one coding style nitpick:


Thanks for doing this!



+  } else {
+  for (int i = 0; i  data.length; i++ )
+   {

That should be:

   }
 else
   {
 for (int i = 0; i  data.length; i++)
   {

But looks fine otherwise.

Thanks,


Thanks, committed.

Andreas


-- 
http://www.worldforge.org/



Interested in RMI

2006-07-21 Thread Hari Shreedharan
Hey guys,I had mailed earlier showing my interest in classpath.The opentasks shows that some work is remaining in RMI.I would like to know from the guys working on RMI, where I can help.Though I maynot be able to start immediately,as I am now shifting, I can help with it in the near 
future.Plz mail the details.Also if any work on networking is also remaining,kindly mention...Cheers,Hari


Re: Howto generate configure?

2006-07-21 Thread Clemens Eisserer

Hello again :-/

Well as far as I know to be able to make dist I guess I have to run
the generated configure-script first, however it fails saying GConf2
is missing.
However I've GConf2 installed, I even updated it to 2.14 to make sure
I use an up-to-date version and its installed in default location ...
will gconf2 also be needed for my embedded build?!

I don't understand, classpath-0.91 builds so nicely but CVS only
causes problems to me.
As far as i know gconf was not needed, the downloadable tarball just
compiled without causing any problems.

Any ideas what could be wrong?

lg Clemens

2006/7/21, Michael Koch [EMAIL PROTECTED]:

On Fri, Jul 21, 2006 at 08:09:33AM +0200, Clemens Eisserer wrote:
 Hello again,

 Thanks for all the help and patience, its really seldom to get such
 amount help ... thanks!

 I now discovered that the debian-based Maemo-scartchbox SDK only comes
 with automake-1.8.5 whereas classpath requires at least 1.9 so it
 bails out with an error message - running autogen.sh on my Fedora Core
 4 box and trying to run the generated configure-file fails since
 symbolic links to e.g. config.sub are not valid.

 I fear I am not experienced enough to update the whole
 build-machinary, however running configure which is distributed as
 part of classpath-0.91 works perfektly.
 How do classpath-developers generate these file without running into
 problems with the symbolic link desaster I experienced.

As long as you build on the machine where you ran autogen.sh this is no
problem. When you want to use everything on a second machine you should
use make dist and use the created classpath-VERSION.tar.gz on the
other machine. It includes all files directly and no symlinks. This way
you can use the latest autotools from fedora and build easily in your
Maemo-scratchbox environemnt.


Cheers,
Michael
--
http://www.worldforge.org/





Re: Howto generate configure?

2006-07-21 Thread Gary Benson
Clemens Eisserer wrote:
 Well as far as I know to be able to make dist I guess I have to
 run the generated configure-script first, however it fails saying
 GConf2 is missing.
 However I've GConf2 installed, I even updated it to 2.14 to make
 sure I use an up-to-date version and its installed in default
 location ...  will gconf2 also be needed for my embedded build?!

You need to install the GConf2 development headers.  On Fedora 
that's the package GConf2-devel, on Debian I'm guessing it's
libgconf2-dev.

Cheers,
Gary



Re: Howto generate configure?

2006-07-21 Thread Michael Koch
On Fri, Jul 21, 2006 at 09:37:43AM +0200, Clemens Eisserer wrote:
 Hello again :-/
 
 Well as far as I know to be able to make dist I guess I have to run
 the generated configure-script first, however it fails saying GConf2
 is missing.
 However I've GConf2 installed, I even updated it to 2.14 to make sure
 I use an up-to-date version and its installed in default location ...
 will gconf2 also be needed for my embedded build?!
 
 I don't understand, classpath-0.91 builds so nicely but CVS only
 causes problems to me.
 As far as i know gconf was not needed, the downloadable tarball just
 compiled without causing any problems.
 
 Any ideas what could be wrong?

You need the gconf development files installed.

Its maybe possible to live without gconf bt configureing with
--disable-gconf.

The gconf support was added after 0.91 release. Another change is the
current CVS depends on newer GTK which Maemo afaik doesnt have. You will
need to update GTK on Maemo (which is a pain if not impossible to do on
your own).


Cheers,
Michael
-- 
http://www.worldforge.org/



Re: Random list of AWT TODOs. DirectFB?

2006-07-21 Thread Philippe Laporte
On Thu, 2006-07-06 at 20:01 +0200, Sven de Marothy wrote:
 On Thu, 2006-07-06 at 15:24 +0200, Juerg Lehni wrote:
 
  But then there was gnu_java_awt_peer_gtk_ComponentGraphics.c, in  
  which the fix will not be that easy:
 [..]
  The code then has various dependencies on X11 that will not run in  
  such a Quartz environment. I'm not into GTK on Windows, but I doubt  
  it will work there either.
 
 Hmm.. the thing here is that the code gets the X pixmap associated with
 the component, and uses the X-surface-drawing backend of Cairo to draw
 to that. I'm not 100% sure of how to adress this, but you/we will
 probably need a replacement for that. Most likely using the Quartz/Win32
 backends for that. (Although I don't know how you create one of those
 for a GTK component under Windows/OS X, but it should be possible
 somehow.) On the plus side, it's relatively little code since most of
 the work is done by the abstract CairoGraphics class.
 
 Another, related, issue is VolatileImage, which maps to an X pixmap,
 and also uses ComponentGraphics (being an X surface). That'll need
 to map to some other native structure (on which Cairo can draw).
 
 So, obviously and unfortunately, it's not just a matter of replacing a
 few X class with GTK equivalents. But on the other hand, I think that's
 the most of it, and luckily it's fairly straightforward to do your own 
 implementation extending CairoGraphics for the various backends.
 
 (The rest of you can thank me here for doing that big refactoring
 separating the Cairo code from the GTK code from the X code ;))

Tack så mycket! (Thanks a whole lot) :-)

Another interesting case is running on GTK-DirectFB. Does someone have
an analogous perspective to share about that one?

Thanks a lot,
-- 
Philippe Laporte





[Bug classpath/28413] [regex] Pattern.MULTILINE | Pattern.DOTALL doesn't match ^ and $

2006-07-21 Thread kaz at maczuka dot gcd dot org


--- Comment #2 from kaz at maczuka dot gcd dot org  2006-07-21 10:11 ---
I have confirmed this bug, and made a patch for this.  I will send the patch to
the cp-patches mailing list later.  


-- 

kaz at maczuka dot gcd dot org changed:

   What|Removed |Added

 AssignedTo|unassigned at gcc dot gnu   |kaz at maczuka dot gcd dot
   |dot org |org
 Status|UNCONFIRMED |ASSIGNED
 Ever Confirmed|0   |1
   Last reconfirmed|-00-00 00:00:00 |2006-07-21 10:11:54
   date||


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=28413



___
Bug-classpath mailing list
Bug-classpath@gnu.org
http://lists.gnu.org/mailman/listinfo/bug-classpath


Harmony, Suns work in progress OSS Java, GNU Classpath and the Java SE front

2006-07-21 Thread theUser BL
Sibnce the end of the last month, there existing precompiled Snapshots of 
Apache Harmony with AWT, Swing and all the Intel-contributed parts.


http://people.apache.org/dist/incubator/harmony/snapshots/


You need still the closed source JVM v2 or v3 to running it:

http://www-128.ibm.com/developerworks/java/jdk/harmony/index.html


Here a little screenshots of GNU Classpaths Swing Activity board running on 
Apache Harmony:


http://mitglied.lycos.de/theuserbl/Bildschirmphoto1.png


There are programs which run better on Harmony and there are programs whioch 
run better on Classpath.


For example, the JFileChooser is a lot of better in Harmony.
But the JColorChooser is better in Classpath I think.
The BeanShell Workplace runs on Harmony better, then it on Classpath ever 
does.

The JTable have already real movable columns in Harmony.

But the security libraries for example existing only for Classpath I think.


Also there existing a corroboration by Robert Brewin at
http://www.infoworld.com/marticle/06/07/17/HNjavaopen_1.html
that Suns Java will be really OpenSource in the future.
He sayd, that it will be in bigger steps. In the Hune of the next year it is 
planned to open the JVM, Swing and some other things.
But why he don't publish already today the first classes under an OpenSource 
license is for me unclear. So it ins't sure, if it is right, what Brewin 
said and it really an OpenSource license will be.




An other point is GNU Classpath at the moment.
GNU Classpath 0.92 was ok. But all the snapshots after it have more and more 
bugs.


- The beanshell no longer runs right.
- If you open in the foxhunt game more fields with pressed mouse key, then 
the fields will no longer open, when the mouse coursor reach the field (or 
button), it opens after the mouse cursor leaves the field.


Then the buttons are wrong drawn since a while. There is a line though the 
buttons.
The titles of internel windows looks wrong and other thing which looks very 
buggy.




Greatings
theuserbl





RE: Harmony, Suns work in progress OSS Java, GNU Classpath and the Java SE front

2006-07-21 Thread theUser BL

Also there existing a corroboration by Robert Brewin at
[a wrong link]


Sorry, but there comes a wrong letter in the link, which I have typed. I 
mean this one here:

http://www.infoworld.com/article/06/07/17/HNjavaopen_1.html

Greatings
theuserbl





RE: Harmony, Suns work in progress OSS Java, GNU Classpath and the Java SE front

2006-07-21 Thread theUser BL

Also there existing a corroboration by Robert Brewin at
[wrong link]


Sorry, but by typing the link, I have written a wrong letter in it.
The right link is
http://www.infoworld.com/article/06/07/17/HNjavaopen_1.html

Greatings
theuserbl





Re: Interested in RMI

2006-07-21 Thread Audrius Meskauskas
The implementation of the jndi naming service (see) 
http://gcc.gnu.org/bugzilla/show_bug.cgi?id=26972 would be both 
interesting, attractive and highly useful (J2EE aplications need this). 
I have fixed the bug itself, but the the implementation is still 
missing. The java API documentation of these classes seems sufficiently 
good to write the naming service providers.


Hari Shreedharan wrote:

Hey guys,

I had mailed earlier showing my interest in classpath.The opentasks 
shows that some work is remaining in RMI.I would like to know from the 
guys working on RMI, where I can help.Though I maynot be able to start 
immediately,as I am now shifting, I can help with it in the near 
future.Plz mail the details.Also if any work on networking is also 
remaining,kindly mention...


Cheers,
Hari





Re: Harmony, Suns work in progress OSS Java, GNU Classpath and the Java SE front

2006-07-21 Thread Dalibor Topic
On Fri, Jul 21, 2006 at 01:02:29PM +, theUser BL wrote:
 Also there existing a corroboration by Robert Brewin at
 [wrong link]
 
 Sorry, but by typing the link, I have written a wrong letter in it.
 The right link is
 http://www.infoworld.com/article/06/07/17/HNjavaopen_1.html
 

thank you for the information. It's nice to see that there is progress
on all sides.

cheers,
dalibor topic

 Greatings
 theuserbl
 
 
 



http://www.infoworld.com/marticle/06/07/17/HNjavaopen_1.html link

2006-07-21 Thread Audrius Meskauskas

theUser BL wrote:

Also there existing a corroboration by Robert Brewin at
http://www.infoworld.com/marticle/06/07/17/HNjavaopen_1.html
that Suns Java will be really OpenSource in the future.

The URL points directly to the windows of God.




Re: Howto generate configure?

2006-07-21 Thread Mark Wielaard
Hi Clemens,

On Fri, 2006-07-21 at 09:37 +0200, Clemens Eisserer wrote:
 I don't understand, classpath-0.91 builds so nicely but CVS only
 causes problems to me.

If you really want build of the current CVS code as if they were release
builds then look at http://builder.classpath.org/dist/ those are
generated by the autobuilder with make dist and so should be as good as
real release snapshots and you don't need any autotools installed for
using them.

Cheers,

Mark




Re: Howto generate configure?

2006-07-21 Thread Clemens Eisserer

Hi Mark,


If you really want build of the current CVS code as if they were release
builds then look at http://builder.classpath.org/dist/ those are
generated by the autobuilder with make dist and so should be as good as
real release snapshots and you don't need any autotools installed for
using them.


Thank you many times, these seem to work :-)

However configure claims that it can't find glib-2 (of course, since
its an embedded platform), I configure classpath it with the following
options:

./configure --disable-gtk-peer --disable-gconf-peer
--enable-local-sockets --enable-escher=/home/ce/escher-0.2.3/
--enable-default-toolkit=gnu.java.awt.peer.x.XToolkit --with-jikes
--prefix=/opt/jamvm143/classpath092pre

Is glib-2 now needed for a default build?

Sorry ... I know I start nerving :-/

lg Clemens



Re: Harmony, Suns work in progress OSS Java, GNU Classpath and the Java SE front

2006-07-21 Thread Tom Tromey
 An other point is GNU Classpath at the moment.
 GNU Classpath 0.92 was ok. But all the snapshots after it have more
 and more bugs.

Please file bug reports.

Tom



CacaoJVM on OS X/Intel

2006-07-21 Thread Casey Marshall
I posted this patch to the Cacao mailing list, too, but I can't tell  
if that's a black hole for me (I couldn't even subscribe...). So,  
attached is a patch that makes Cacao work on OS X/Intel. There are  
still some bugs (I can't run the full mauve test suite with cacao  
running the harness, but, with jamvm running the harness, and cacao  
the test VM, I get 888 fails, and a lot of these are because I have  
no AWT peers enabled) but it does seem to work.


Thanks.

Index: src/vm/jit/i386/darwin/md-os.c
===
--- src/vm/jit/i386/darwin/md-os.c  (revision 0)
+++ src/vm/jit/i386/darwin/md-os.c  (revision 0)
@@ -0,0 +1,140 @@
+/* src/vm/jit/i386/darwin/md-os.c - machine dependent i386 Darwin functions
+
+   Copyright (C) 1996-2005, 2006 R. Grafl, A. Krall, C. Kruegel,
+   C. Oates, R. Obermaisser, M. Platter, M. Probst, S. Ring,
+   E. Steiner, C. Thalinger, D. Thuernbeck, P. Tomsich, C. Ullrich,
+   J. Wenninger, Institut f. Computersprachen - TU Wien, C. Marshall
+
+   This file is part of CACAO.
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public License as
+   published by the Free Software Foundation; either version 2, or (at
+   your option) any later version.
+
+   This program is distributed in the hope that it will be useful, but
+   WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+   02110-1301, USA.
+
+   Contact: [EMAIL PROTECTED]
+
+   Authors: Christian Thalinger
+
+   Changes:
+
+   $Id$
+
+   Based on ../freebsd/md-os.c and ../../powerpc/darwin/md-os.c;
+   modified for Darwin/x86 by Casey Marshall.
+*/
+
+
+#include config.h
+
+#include ucontext.h
+
+#include vm/jit/i386/md-abi.h
+
+#include vm/exceptions.h
+#include vm/signallocal.h
+#include vm/jit/asmpart.h
+#include vm/jit/stacktrace.h
+
+
+/* md_signal_handler_sigsegv 
***
+
+   NullPointerException signal handler for hardware null pointer
+   check.
+
+***/
+
+void md_signal_handler_sigsegv(int sig, siginfo_t *siginfo, void *_p)
+{
+   ucontext_t *_uc;
+   mcontext_t  _mc;
+   i386_thread_state_t *_ss;
+   u1 *sp;
+   u1 *ra;
+   u1 *xpc;
+
+   _uc = (ucontext_t *) _p;
+   _mc = _uc-uc_mcontext;
+   _ss = _mc-ss;
+   
+   sp  = (u1 *) _ss-esp;
+   xpc = (u1 *) _ss-eip;
+   ra  = xpc;  /* return address is equal to xpc   
  */
+
+   _ss-eax =
+   (ptrint) stacktrace_hardware_nullpointerexception(NULL, sp, ra, 
xpc);
+   
+   _ss-ecx = (ptrint) xpc;  /* REG_ITMP2_XPC 
*/
+   _ss-eip = (ptrint) asm_handle_exception;
+}
+
+
+/* md_signal_handler_sigfpe 

+
+   ArithmeticException signal handler for hardware divide by zero
+   check.
+
+***/
+
+void md_signal_handler_sigfpe(int sig, siginfo_t *siginfo, void *_p)
+{
+   ucontext_t *_uc;
+   mcontext_t  _mc;
+   i386_thread_state_t *_ss;
+   u1 *sp;
+   u1 *ra;
+   u1 *xpc;
+
+   _uc = (ucontext_t *) _p;
+   _mc = _uc-uc_mcontext;
+   _ss = _mc-ss;
+
+   sp  = (u1 *) _ss-esp;
+   xpc = (u1 *) _ss-eip;
+   ra  = xpc;  /* return address is equal to xpc   
  */
+
+   _ss-eax =
+   (ptrint) stacktrace_hardware_arithmeticexception(NULL, sp, ra, 
xpc);
+   
+   _ss-ecx = (ptrint) xpc;  /* REG_ITMP2_XPC 
*/
+   _ss-eip = (ptrint) asm_handle_exception;
+}
+
+
+#if defined(ENABLE_THREADS)
+void thread_restartcriticalsection(ucontext_t *uc)
+{
+   void *critical;
+   mcontext_t _mc = uc-uc_mcontext;
+   i386_thread_state_t *_ss = _mc-ss;
+
+   critical = critical_find_restart_point((void *) _ss-eip);
+
+   if (critical)
+   _ss-eip = (ptrint) critical;
+}
+#endif
+
+
+/*
+ * These are local overrides for various environment variables in Emacs.
+ * Please do not remove this and leave it at the end of the file, where
+ * Emacs will automagically detect them.
+ * -
+ * Local variables:
+ * mode: c
+ * indent-tabs-mode: t
+ * c-basic-offset: 4
+ * tab-width: 4
+ * End:
+ */
Index: gnu/java/awt/peer/gtk/CairoSurface.java
===
RCS file: 
/cvsroot/classpath/classpath/gnu/java/awt/peer/gtk/CairoSurface.java,v

retrieving revision 1.13
diff -u -r1.13 CairoSurface.java
--- gnu/java/awt/peer/gtk/CairoSurface.java 17 Jul 2006 22:41:03 
- 1.13

+++ gnu/java/awt/peer/gtk/CairoSurface.java 21 Jul 2006 22:38:01 -
@@ -175,9 +175,9 @@
 int[] data = image.getPixels();

 // Swap ordering from GdkPixbuf to Cairo
-for(int i = 0; i  data.length; i++ )
+if (ByteOrder.nativeOrder() == ByteOrder.BIG_ENDIAN)
   {
-   if (ByteOrder.nativeOrder() == ByteOrder.BIG_ENDIAN)
+   for (int i = 0; i  data.length; i++ )
  {
// On a big endian system we get a RRGGBBAA data array.
int alpha = (data[i]  0xFF);
@@ -195,7 +195,10 @@
  | ( b   0x00FF);
  }
  }
-   else
+  }
+else
+  {
+   for (int i = 0; i  data.length; i++ )
  {
// On a little endian system we get a AABBGGRR data array.
int alpha = (data[i]  0xFF00)  24;



[cp-patches] FYI: fix for PR 28100

2006-07-21 Thread Raif S. Naffah
hello all,

the attached patch adds support for handling 1 and 2, in addition to the 
existing 3, DES keys to the triple-DES cipher.

the Mauve test TestOfTripleDES (in gnu.testlet.gnu.javax.crypto.cipher) was 
amended to test the new changes.

2006-07-22  Raif S. Naffah  [EMAIL PROTECTED]

PR Classpath/28100
* gnu/javax/crypto/cipher/TripleDES.java: Updated documentation.
(KEY_SIZE): Likewise.
(adjustParity(int,byte[],int): New method.
(adjustParity(byte[],int): Call above method with 3 as 1st argument.
(isParityAdjusted(int,byte[],int)): New method.
(isParityAdjusted): Call above method with 3 as 1st argument.
(keySizes): Add 8 and 16 as other valid key sizes.
(makeKey): Amended to cater for 1, 2 and 3 independent DES keys.


cheers;
rsn
Index: TripleDES.java
===
RCS file: /cvsroot/classpath/classpath/gnu/javax/crypto/cipher/TripleDES.java,v
retrieving revision 1.3
diff -u -r1.3 TripleDES.java
--- TripleDES.java	25 Jun 2006 12:01:33 -	1.3
+++ TripleDES.java	21 Jul 2006 22:57:54 -
@@ -40,17 +40,21 @@

 import gnu.java.security.Registry;

+import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Iterator;
 import java.security.InvalidKeyException;

 /**
  * Triple-DES, 3DES, or DESede is a icombined cipher/i that uses three
- * iterations of the Data Encryption Standard cipher to improve the security (at
- * the cost of speed) of plain DES.
+ * iterations of the Data Encryption Standard cipher to theoretically improve
+ * the security of plain DES, at the cost of speed.
  * p
  * Triple-DES runs the DES algorithm three times with three independent 56 bit
  * keys. To encrypt:
  * blockquoteiCsubi/sub = Esubk3/sub ( Esubk2/subsup-1/sup (
  * Esubk1/sub ( Psubi/sub )))/i
  * /blockquote
@@ -75,10 +79,8 @@
 {
   /** Triple-DES only operates on 64 bit blocks. */
   public static final int BLOCK_SIZE = 8;
-
-  /** Triple-DES uses 168 bits of a parity-adjusted 192 bit key. */
+  /** By default, Triple-DES uses 168 bits of a parity-adjusted 192 bit key. */
   public static final int KEY_SIZE = 24;
-
   /** The underlying DES instance. */
   private DES des;

@@ -92,21 +94,45 @@
   }

   /**
-   * Transform a key so it will be parity adjusted.
+   * Convenience method which calls the method with same name and three
+   * arguments, passing code3/code as the value of the first parameter.
*
* @param kb The key bytes to adjust.
* @param offset The starting offset into the key bytes.
-   * @see DES#adjustParity(byte[],int)
*/
   public static void adjustParity(byte[] kb, int offset)
   {
+adjustParity(3, kb, offset);
+  }
+
+  /**
+   * Adjusts, in-situ, the parity of the designated bytes, so they can be used
+   * as DES keys for a 3-DES 1-, 2- or 3-key cipher.
+   *
+   * @param keyCount the number of independent DES keys. Can be either
+   *  code1/code, code2/code or code3/code. Any other value
+   *  will cause an [EMAIL PROTECTED] IllegalArgumentException} to be raised.
+   * @param kb the array containing the key bytes to adjust. MUST have at least
+   *  code8 * keyCount/code bytes starting at offset position
+   *  codeoffset/code, otherwise an
+   *  [EMAIL PROTECTED] ArrayIndexOutOfBoundsException} will be raised.
+   * @param offset the starting offset into the array.
+   * @see DES#adjustParity(byte[],int)
+   */
+  public static void adjustParity(int keyCount, byte[] kb, int offset)
+  {
+if (keyCount  1 || keyCount  3)
+  throw new IllegalArgumentException(Invalid keyCount value:  + keyCount);
 DES.adjustParity(kb, offset);
-DES.adjustParity(kb, offset + 8);
-DES.adjustParity(kb, offset + 16);
+if (keyCount  1)
+  DES.adjustParity(kb, offset + 8);
+if (keyCount  2)
+  DES.adjustParity(kb, offset + 16);
   }

   /**
-   * Tests if a byte array has already been parity adjusted.
+   * Convenience method which calls the method with same name and three
+   * arguments, passing code3/code as the value of the first parameter.
*
* @param kb The key bytes to test.
* @param offset The starting offset into the key bytes.
@@ -117,9 +143,37 @@
*/
   public static boolean isParityAdjusted(byte[] kb, int offset)
   {
-return DES.isParityAdjusted(kb, offset)
-DES.isParityAdjusted(kb, offset + 8)
-DES.isParityAdjusted(kb, offset + 16);
+return isParityAdjusted(3, kb, offset);
+  }
+
+  /**
+   * Tests if enough bytes, expected to be used as DES keys for a 3-DES 1-, 2-
+   * or 3-key cipher, located in a designated byte array, has already been
+   * parity adjusted.
+   *
+   * @param keyCount the number of 
@@ -40,17 +40,21 @@
  * p
- * Triple-DES runs the DES algorithm three times with three independent 56 bit
- * keys. To encrypt:
+ * Triple-DES runs the DES algorithm three times with one, two or three
+ * independent 56-bit (DES) keys. When used with one DES key, the cipher behaves
+ * exactly like a (slower) DES.
+ * p
+ * To encrypt:
  * blockquoteiCsubi/sub = Esubk3/sub ( Esubk2/subsup-1/sup (
  * Esubk1/sub ( Psubi/sub )))/i

[cp-testresults] FAIL: regressions for mauve-jamvm on Fri Jul 21 12:16:29 UTC 2006

2006-07-21 Thread cpdev
Baseline from: Thu Jul 20 20:45:12 UTC 2006

Regressions:
FAIL: gnu.javax.crypto.jce.TestOfDHKeyAgreement
FAIL: gnu.javax.crypto.jce.TestOfDHKeyFactory
FAIL: gnu.javax.crypto.key.srp6.TestOfSRPKeyGeneration

Improvements:
PASS: gnu.java.security.jce.TestOfFormat
PASS: gnu.java.security.jce.TestOfKeyFactory

New fails:
FAIL: java.awt.image.Kernel.constructor:
FAIL: java.lang.Character.unicode
FAIL: java.lang.Thread.sleep:

Totals:
PASS: 2551
XPASS: 0
FAIL: 208
XFAIL: 0


___
Classpath-testresults mailing list
Classpath-testresults@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-testresults


[cp-testresults] FAIL: regressions for mauve-cacao on Fri Jul 21 12:53:56 UTC 2006

2006-07-21 Thread cpdev
Baseline from: Fri Jul 21 04:58:30 UTC 2006

Regressions:
FAIL: gnu.javax.crypto.key.srp6.TestOfSRPKeyGeneration
FAIL: java.net.ServerSocket.ServerSocketTest

New fails:
FAIL: gnu.java.security.sig.rsa.TestOfRSAPSSSignature:
FAIL: java.awt.image.Kernel.constructor:

Totals:
PASS: 2540
XPASS: 0
FAIL: 219
XFAIL: 0


___
Classpath-testresults mailing list
Classpath-testresults@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-testresults


[cp-testresults] FAIL: regressions for mauve-cacao on Sat Jul 22 04:14:03 UTC 2006

2006-07-21 Thread cpdev
Baseline from: Fri Jul 21 04:58:30 UTC 2006

Regressions:
FAIL: java.net.ServerSocket.ServerSocketTest

New fails:
FAIL: gnu.java.security.sig.rsa.TestOfRSAPSSSignature:
FAIL: gnu.javax.crypto.cipher.TestOfTripleDES:
FAIL: java.awt.Graphics.TestPaintGraphics:
FAIL: java.awt.image.Kernel.constructor:

Totals:
PASS: 2540
XPASS: 0
FAIL: 219
XFAIL: 0


___
Classpath-testresults mailing list
Classpath-testresults@gnu.org
http://lists.gnu.org/mailman/listinfo/classpath-testresults


Re: Howto generate configure?

2006-07-21 Thread Clemens Eisserer

Hello again,

Thanks for all the help and patience, its really seldom to get such
amount help ... thanks!

I now discovered that the debian-based Maemo-scartchbox SDK only comes
with automake-1.8.5 whereas classpath requires at least 1.9 so it
bails out with an error message - running autogen.sh on my Fedora Core
4 box and trying to run the generated configure-file fails since
symbolic links to e.g. config.sub are not valid.

I fear I am not experienced enough to update the whole
build-machinary, however running configure which is distributed as
part of classpath-0.91 works perfektly.
How do classpath-developers generate these file without running into
problems with the symbolic link desaster I experienced.

Sorry for all the traffic :-/

lg Clemens

2006/7/20, Gary Benson [EMAIL PROTECTED]:

Hi Clemens,

Clemens Eisserer wrote:
 I would like to try out Classpath-CVS to experiment a bit with Roman's
 great xawt-implementation.
 However in CVS there are no scripts like configure available

The script autogen.sh will generate the configure script for you.

Cheers,
Gary






Re: Howto generate configure?

2006-07-21 Thread Michael Koch
On Fri, Jul 21, 2006 at 08:09:33AM +0200, Clemens Eisserer wrote:
 Hello again,
 
 Thanks for all the help and patience, its really seldom to get such
 amount help ... thanks!
 
 I now discovered that the debian-based Maemo-scartchbox SDK only comes
 with automake-1.8.5 whereas classpath requires at least 1.9 so it
 bails out with an error message - running autogen.sh on my Fedora Core
 4 box and trying to run the generated configure-file fails since
 symbolic links to e.g. config.sub are not valid.
 
 I fear I am not experienced enough to update the whole
 build-machinary, however running configure which is distributed as
 part of classpath-0.91 works perfektly.
 How do classpath-developers generate these file without running into
 problems with the symbolic link desaster I experienced.

As long as you build on the machine where you ran autogen.sh this is no
problem. When you want to use everything on a second machine you should
use make dist and use the created classpath-VERSION.tar.gz on the
other machine. It includes all files directly and no symlinks. This way
you can use the latest autotools from fedora and build easily in your
Maemo-scratchbox environemnt.


Cheers,
Michael
Index: src/vm/jit/i386/darwin/Makefile.am
===
--- 

Re: Howto generate configure?

2006-07-21 Thread Paul Jenner
Hi Clemens,

On Fri, 2006-07-21 at 17:23 +0200, Clemens Eisserer wrote:
 However configure claims that it can't find glib-2 (of course, since
 its an embedded platform), I configure classpath it with the following
 options:
 
 ./configure --disable-gtk-peer --disable-gconf-peer
 --enable-local-sockets --enable-escher=/home/ce/escher-0.2.3/
 --enable-default-toolkit=gnu.java.awt.peer.x.XToolkit --with-jikes
 --prefix=/opt/jamvm143/classpath092pre

Try adding --disable-plugin to the configure options. gcjwebplugin
requires Glib.

Hope this helps,

Paul

-- 
Paul Jenner [EMAIL PROTECTED]




Re: Harmony, Suns work in progress OSS Java, GNU Classpath and the Java SE front

2006-07-21 Thread Casey Marshall

On Jul 21, 2006, at 5:48 AM, theUser BL wrote:


An other point is GNU Classpath at the moment.
GNU Classpath 0.92 was ok. But all the snapshots after it have more  
and more bugs.




Surely you don't mean 0.92, which doesn't exist yet, and neither do  
snapshots after it.


Also, please let us know what these bugs are. Just saying that we're  
inferior to Harmony's classlib in some places isn't useful to us.


PGP.sig
Description: This is a digitally signed message part


[Bug crypto/28333] CBC Ciphers do not contain the correct ParameterSpec

2006-07-21 Thread raif at swiftdsl dot com dot au


--- Comment #1 from raif at swiftdsl dot com dot au  2006-07-21 23:57 
---
Matt,

can you please confirm that this patch
(http://developer.classpath.org/pipermail/classpath-patches/2006-July/003381.html)
fixes this problem?  if it does i'd like to close this one.


TIA + cheers;
rsn


-- 


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=28333



___
Bug-classpath mailing list
Bug-classpath@gnu.org
http://lists.gnu.org/mailman/listinfo/bug-classpath


[commit-cp] classpath/java/awt LightweightDispatcher.java C...

2006-07-21 Thread Roman Kennke
CVSROOT:/cvsroot/classpath
Module name:classpath
Changes by: Roman Kennke rabbit78 06/07/21 17:27:24

Modified files:
java/awt   : LightweightDispatcher.java 
.  : ChangeLog 

Log message:
2006-07-20  Roman Kennke  [EMAIL PROTECTED]

* java/awt/LightweightDispatcher.java
(findTarget): Also consider components that have their eventMask
set, for compatibility with stonage AWT. Optimized check
for MouseListener.
(handleMouseEvent): Likewise.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/java/awt/LightweightDispatcher.java?cvsroot=classpathr1=1.11r2=1.12
http://cvs.savannah.gnu.org/viewcvs/classpath/ChangeLog?cvsroot=classpathr1=1.8176r2=1.8177




[commit-cp] classpath ChangeLog java/awt/dnd/DragSource.jav...

2006-07-21 Thread Lillian Angel
CVSROOT:/cvsroot/classpath
Module name:classpath
Changes by: Lillian Angel langel  06/07/21 20:44:30

Modified files:
.  : ChangeLog 
java/awt/dnd   : DragSource.java 
gnu/java/awt/dnd: GtkMouseDragGestureRecognizer.java 

Log message:
2006-07-20  Lillian Angel  [EMAIL PROTECTED]

* gnu/java/awt/dnd/GtkMouseDragGestureRecognizer.java
(GtkMouseDragGestureRecognizer): New constructor.
(GtkMouseDragGestureRecognizer): New constructor.
(GtkMouseDragGestureRecognizer): New constructor.
(mouseClicked): Removed FIXME.
(mousePressed): Implemented.
(mouseReleased): Implemented.
(mouseEntered): Implemented.
(mouseDragged): Implemented to check mouse point and trigger 
origin.
(mouseMoved): Removed FIXME.
(getDropActionFromEvent): New helper function used to convert 
mouse event
modifiers to a drop action.
* java/awt/dnd/DragSource.java
(getDragThreshold): Changed to return some arbitrary value for 
testing
purposes.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/ChangeLog?cvsroot=classpathr1=1.8177r2=1.8178
http://cvs.savannah.gnu.org/viewcvs/classpath/java/awt/dnd/DragSource.java?cvsroot=classpathr1=1.10r2=1.11
http://cvs.savannah.gnu.org/viewcvs/classpath/gnu/java/awt/dnd/GtkMouseDragGestureRecognizer.java?cvsroot=classpathr1=1.1r2=1.2




[commit-cp] classpath ChangeLog gnu/java/awt/dnd/GtkMouseDr...

2006-07-21 Thread Lillian Angel
CVSROOT:/cvsroot/classpath
Module name:classpath
Changes by: Lillian Angel langel  06/07/21 21:05:14

Modified files:
.  : ChangeLog 
gnu/java/awt/dnd: GtkMouseDragGestureRecognizer.java 

Log message:
2006-07-20  Lillian Angel  [EMAIL PROTECTED]

* gnu/java/awt/dnd/GtkMouseDragGestureRecognizer.java:
Removed unused fields.
(GtkMouseDragGestureRecognizer): Removed initializations.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/ChangeLog?cvsroot=classpathr1=1.8178r2=1.8179
http://cvs.savannah.gnu.org/viewcvs/classpath/gnu/java/awt/dnd/GtkMouseDragGestureRecognizer.java?cvsroot=classpathr1=1.2r2=1.3




[commit-cp] classpath ChangeLog java/util/concurrent/CopyOn... [generics-branch]

2006-07-21 Thread Tom Tromey
CVSROOT:/cvsroot/classpath
Module name:classpath
Branch: generics-branch
Changes by: Tom Tromey tromey 06/07/21 22:41:54

Modified files:
.  : ChangeLog 
java/util/concurrent: CopyOnWriteArrayList.java 

Log message:
2006-07-21  Carsten Neumann  [EMAIL PROTECTED]

* java/util/CopyOnWriteArrayList.java (indexOf(E, int)): New 
method.
(lastIndexOf(E, int)): Likewise.
(add(E)): Increase the size of newData array by one.
(add(int, E)): Likewise.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/ChangeLog?cvsroot=classpathonly_with_tag=generics-branchr1=1.2386.2.284r2=1.2386.2.285
http://cvs.savannah.gnu.org/viewcvs/classpath/java/util/concurrent/CopyOnWriteArrayList.java?cvsroot=classpathonly_with_tag=generics-branchr1=1.1.2.1r2=1.1.2.2




[commit-cp] classpath ChangeLog gnu/java/awt/peer/gtk/Cairo...

2006-07-21 Thread Andreas Tobler
CVSROOT:/cvsroot/classpath
Module name:classpath
Changes by: Andreas Tobler andreast   06/07/21 22:51:38

Modified files:
.  : ChangeLog 
gnu/java/awt/peer/gtk: CairoSurface.java 

Log message:
2006-07-22  Andreas Tobler  [EMAIL PROTECTED]

* gnu/java/awt/peer/gtk/CairoSurface.java (CairoSurface): 
Rearrange
code for the pixel swap routine to be more efficient.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/ChangeLog?cvsroot=classpathr1=1.8179r2=1.8180
http://cvs.savannah.gnu.org/viewcvs/classpath/gnu/java/awt/peer/gtk/CairoSurface.java?cvsroot=classpathr1=1.13r2=1.14




[commit-cp] classpath ChangeLog gnu/javax/crypto/cipher/Tri...

2006-07-21 Thread Raif S. Naffah
CVSROOT:/cvsroot/classpath
Module name:classpath
Changes by: Raif S. Naffah raif   06/07/21 23:10:28

Modified files:
.  : ChangeLog 
gnu/javax/crypto/cipher: TripleDES.java 

Log message:
2006-07-22  Raif S. Naffah  [EMAIL PROTECTED]

PR Classpath/28100
* gnu/javax/crypto/cipher/TripleDES.java: Updated documentation.
(KEY_SIZE): Likewise.
(adjustParity(int,byte[],int): New method.
(adjustParity(byte[],int): Call above method with 3 as 1st 
argument.
(isParityAdjusted(int,byte[],int)): New method.
(isParityAdjusted): Call above method with 3 as 1st argument.
(keySizes): Add 8 and 16 as other valid key sizes.
(makeKey): Amended to cater for 1, 2 and 3 independent DES keys.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/classpath/ChangeLog?cvsroot=classpathr1=1.8180r2=1.8181
http://cvs.savannah.gnu.org/viewcvs/classpath/gnu/javax/crypto/cipher/TripleDES.java?cvsroot=classpathr1=1.3r2=1.4